"""Unit tests for strunk_white_eos."""
# from __future__ import absolute_import


# from .check import Check
# from proselint.checks.strunkwhite import elementary_composition as chk


# class TestCheck(Check):
#     """Define the suite of checks."""

#     __test__ = True

#     @property
#     def this_check(self):
#         return chk

#     def test_with_utilized(self):
#         """Don't produce an error when 'use' is used correctly."""
#         assert self.check("I use a hammer to drive nails into wood.")

#     def test_no_utilized(self):
#         """Produce an error when 'utilize' is used in place of 'use'."""
#         assert not self.check("I utilize a hammer to drive nails into wood.")
